import { OneCutPlayer, DefaultResourceLoader } from "./runtime/picocut-lib.es.js" //Player
import { sceneJson } from "./scene.js"; //Scene description json
import { urlConfig } from "./url-config.js"; //file resource configuration

//Resize canvas when windo resizes
const resizeCanvas = () => {
	player.resize(window.innerWidth, window.innerHeight);
	player.renderImmediate();
}
window.onresize = () => {resizeCanvas()};

//Scrolling control
let prevScrollPosition;
let ring1Timer = 0.0;
let ring2Timer = 0.0;
let prevTime = Date.now();
const checkScroll = () => {
	window.requestAnimationFrame(() => {
		//Figure out where current scroll is
		const scrollPosition = window.scrollY;
		const totalHeight = document.body.scrollHeight - window.innerHeight;
		const scrollNormalized = (scrollPosition / totalHeight);
		
		let normalized = scrollNormalized * player.document.timeline.length;
		//Set player's time/playhead position to scroll position.
		player.seek(normalized);
		let deltaTime = (Date.now() - prevTime);
		ring1Timer += deltaTime * 0.04;
		ring2Timer = ring1Timer + 220;
		player.setFloatParameter("Ring1Rotation", ring1Timer);
		player.setFloatParameter("Ring2Rotation", ring2Timer);
		prevTime = Date.now();
		//Update every frame
		checkScroll();
		
	});
}

//Demo colors to choose from. Values range from 0-1. But since rendering is in HDR, they can go beyond 1 for more bloom
const colors = [
	[1.0, 0.65, 0.1, 1.0], 
	[0.25, 1.0, 0.25, 1.0], 
	[0.35, 0.65, 1.0, 1.0],
	[1.0, 0.12, 0.04, 1.0],
];

//Ring buttons & data
const ringButtons = [
	document.getElementById('btn-ring-1'),
	document.getElementById('btn-ring-2'), 
	document.getElementById('btn-ring-3'),
	document.getElementById('btn-ring-4'),
];
ringButtons[0].onclick = () => {setRingColor(0)}
ringButtons[1].onclick = () => {setRingColor(1)}
ringButtons[2].onclick = () => {setRingColor(2)}
ringButtons[3].onclick = () => {setRingColor(3)}


//Text buttons & data
const textButtons = [
	document.getElementById('btn-text-1'),
	document.getElementById('btn-text-2'), 
	document.getElementById('btn-text-3'),
	document.getElementById('btn-text-4'),
];
textButtons[0].onclick = () => {setTextColor(0)}
textButtons[1].onclick = () => {setTextColor(1)}
textButtons[2].onclick = () => {setTextColor(2)}
textButtons[3].onclick = () => {setTextColor(3)}

//Helper for button selection visuals
const setSelectionClass = (index, buttonArray) => {
	for(let i = 0; i < buttonArray.length; i++) {
		let classList = index === i ? "button-color btn-selected" : "button-color";
		buttonArray[i].classList = [classList];
	}
}

//Ring and text color set helpers
const setTextColor = (index) => {
	let c = colors[index];
	player.setColorParameter("TextColor", c[0], c[1], c[2], c[3]);
	setSelectionClass(index, textButtons);
	player.renderImmediate();
}
const setRingColor = (index) => {
	let c = colors[index];
	player.setColorParameter("RingColor", c[0], c[1], c[2], c[3]);
	setSelectionClass(index, ringButtons);
	player.renderImmediate();
}

let canvas = document.getElementById('canvas'); //Canvas html element to render to
let player = new OneCutPlayer(new DefaultResourceLoader(urlConfig), canvas, sceneJson);
resizeCanvas();
setTextColor(0);
setRingColor(3);
checkScroll();
